@@ -25,7 +25,7 @@ shinyUI(tagList(
                                includeCSS("css/styles.css"),
                                includeScript("js/scroll.js"),
                                conditionalPanel("input.tabs == 0",
-                                                # actionButton('load', 'HACK'),
+                                                #actionButton('load', 'HACK'),
                                                 includeMarkdown("Rmd/text_intro_tab.Rmd")
                                ),
                                # COMPONENT 1 ####
@@ -69,10 +69,10 @@ shinyUI(tagList(
                                                                  uiTop('leaflet.extras', "Extra functionality for 'leaflet' Package"),
                                                                  HTML('<hr>'),
                                                                  selectOccs_UI('c2_selectOccs'),
-                                                                 HTML('<font color="blue"><em>NOTE</em></font> 
-                                                                 : To <em>begin</em> drawing, click hexagon icon on map toolbar, 
-                                                                 and when complete, press "Finish" and then the "Select Occurrences" 
-                                                                 button. To <em>erase</em> the polygon, click the Trash icon and "Clear All".'), br(), br(),
+                                                                 strong("Select occurrences intersecting drawn polygon"), br(),
+                                                                 "(", HTML("<font color='blue'><b>NOTE</b></font>"), 
+                                                                 ': to begin drawing, click hexagon icon on map toolbar, 
+                                                                 and when complete, press "Finish" and then the "Select Occurrences" button)', br(), br(),
                                                                  actionButton("goSelectOccs", "Select Occurrences")
                                                 ),
                                                 conditionalPanel("input.procOccSel == 'remID'",
@@ -130,7 +130,7 @@ shinyUI(tagList(
                                                 # strong("Download environmental predictors"), br(), br(),
                                                 # downloadButton('dlEnvs', "Download"),
                                                 HTML('<hr>'),
-                                                uiBottom("Jamie M. Kass, Robert P. Anderson", 'raster', "Robert J. Hijmans, Jacob van Etten, Joe Cheng, Matteo Mattiuzzu, 
+                                                uiBottom("Jamie M. Kass, Gonzalo E. Pinilla-Buitrago, Robert P. Anderson", 'raster', "Robert J. Hijmans, Jacob van Etten, Joe Cheng, Matteo Mattiuzzu, 
                                                          Michael Sumner, Jonathan A. Greenberg, Oscar Perpinan Lamigueriro, Andrew Bevan, 
                                                          Etienne B. Racine, Ashton Shortridge"),
                                                 " | ", a("WorldClim", href="http://worldclim.org", target="_blank")
@@ -209,8 +209,9 @@ shinyUI(tagList(
                                                 HTML('<hr>'),
                                                 conditionalPanel("input.enmSel == 'Maxent'",
                                                                  div('Module: Maxent', id="mod"),
-                                                                 uiTop('ENMeval', 'Automated Runs and Evaluations of Ecological Niche Models'),
+                                                                 uiTop('ENMeval', 'Automated Runs and Evaluations of Ecological Niche Models using Maxent GUI (Java)'),
                                                                  uiTop('dismo', 'Species Distribution Modeling'),
+                                                                 uiTop('maxnet', "Fitting 'Maxent' Species Distribution Models with 'glmnet'"),
                                                                  HTML('<hr>'),
                                                                  htmlOutput('maxentJar'), br(),
                                                                  "(", HTML("<font color='blue'><b>NOTE</b></font>"), 
@@ -228,10 +229,11 @@ shinyUI(tagList(
                                                 HTML('<hr>'),
                                                 downloadButton('dlEvalTbl', "Download CSV"),
                                                 HTML('<hr>'),
-                                                uiBottom("Jamie M. Kass, Robert Muscarella, Bruno Vilela, Robert P. Anderson", 'ENMeval', 'Robert Muscarella, Peter J. Galante, Mariano Soley-Guardia, Robert A. Boria,
+                                                uiBottom("Jamie M. Kass, Gonzalo E. Pinilla-Buitrago, Robert Muscarella, Bruno Vilela, Robert P. Anderson", 'ENMeval', 'Robert Muscarella, Peter J. Galante, Mariano Soley-Guardia, Robert A. Boria,
                                                          Jamie M. Kass, Maria Uriarte, Robert P. Anderson'),
                                                 " | ", a("software note", href="http://onlinelibrary.wiley.com/doi/10.1111/2041-210X.12261/abstract", target = "_blank"), br(),
-                                                uiBottom(NULL, 'dismo', 'Robert J. Hijmans, Steven Phillips, John Leathwick, Jane Elith')
+                                                uiBottom(NULL, 'dismo', 'Robert J. Hijmans, Steven Phillips, John Leathwick, Jane Elith'), br(),
+                                                uiBottom(NULL, 'maxnet', 'Steven Phillips')
                                ),
                                # COMPONENT 7 ####
                                conditionalPanel("input.tabs == 7", 
@@ -278,7 +280,7 @@ shinyUI(tagList(
                                                                  " | ", a("software note", href="http://onlinelibrary.wiley.com/doi/10.1111/2041-210X.12261/abstract", target = "_blank"), br()
                                                 ),
                                                 conditionalPanel("input.visSel != 'mxEval'",
-                                                                 uiBottom("Jamie M. Kass, Bruno Vilela, Robert P. Anderson")
+                                                                 uiBottom("Jamie M. Kass, Gonzalo E. Pinilla-Buitrago, Bruno Vilela, Robert P. Anderson")
                                                 ),
                                                 uiBottom(NULL, 'dismo', 'Robert J. Hijmans, Steven Phillips, John Leathwick, Jane Elith')
                                ),
@@ -295,21 +297,14 @@ shinyUI(tagList(
                                                                  div('Module: Project to New Extent', id="mod"),
                                                                  uiTop('dismo', 'Species Distribution Modeling'),
                                                                  HTML('<hr>'),
-                                                                 HTML('<font color="blue"><em>NOTE</em></font> 
-                                                                 : To <em>begin</em> drawing, click hexagon icon on map toolbar, 
-                                                                      and when complete, press "Finish" and then the "Select Occurrences" 
-                                                                      button. To <em>erase</em> the polygon, click the Trash icon and "Clear All".'), br(), br(),
-                                                                 strong("Project model to current extent"), br(), br(),
-                                                                 actionButton('goProjectArea', "Project"), br(), br(),
-                                                                 projectArea_UI('c8_projectArea')),
+                                                                 strong("Project model to new extent"), br(),
+                                                                 em("Using the polygon drawing tool"), br(), br(),
+                                                                 projectArea_UI('c8_projectArea'), 
+                                                                 actionButton('goProjectArea', "Project")),
                                                 conditionalPanel("input.projSel == 'projTime'",
                                                                  div('Module: Project to New Time', id="mod"),
                                                                  uiTop('dismo', 'Species Distribution Modeling'),
                                                                  HTML('<hr>'),
-                                                                 HTML('<font color="blue"><em>NOTE</em></font> 
-                                                                 : To <em>begin</em> drawing, click hexagon icon on map toolbar, 
-                                                                 and when complete, press "Finish" and then the "Select Occurrences" 
-                                                                 button. To <em>erase</em> the polygon, click the Trash icon and "Clear All".'), br(), br(),
                                                                  projectTime_UI('c8_projectTime'),
                                                                  strong("Project model to new time for current extent"), br(), br(),
                                                                  actionButton('goProjectTime', "Project")),
@@ -320,7 +315,8 @@ shinyUI(tagList(
                                                                  envSimilarity_UI('c8_envSimilarity'),
                                                                  strong("Calculate MESS for current extent"), br(), br(),
                                                                  actionButton('goEnvSimilarity', "Calculate MESS")),
-                                                strong("Reset projection extent"), br(), br(),
+                                                br(), br(),
+                                                strong("Reset projection raster"), br(), br(),
                                                 actionButton("goResetProj", "Reset"),
                                                 HTML('<hr>'),
                                                 selectInput('projFileType', label = "Select download file type",
@@ -329,7 +325,7 @@ shinyUI(tagList(
                                                 strong("Download displayed raster"), br(), br(),
                                                 downloadButton('dlProj', "Download"),
                                                 HTML('<hr>'),
-                                                uiBottom("Jamie M. Kass, Bruno Vilela, Robert P. Anderson", 'dismo', 'Robert J. Hijmans, Steven Phillips, John Leathwick, Jane Elith')
+                                                uiBottom("Jamie M. Kass, Gonzalo E. Pinilla-Buitrago, Bruno Vilela, Robert P. Anderson", 'dismo', 'Robert J. Hijmans, Steven Phillips, John Leathwick, Jane Elith')
                                ),
                                # SESSION CODE ####
                                conditionalPanel("input.tabs == 'rmd'",
@@ -342,7 +338,7 @@ shinyUI(tagList(
                                                             choices = list("Rmd", "PDF", "HTML", "Word")),
                                                 downloadButton('dlRMD', 'Download Session Code'),
                                                 HTML('<hr>'),
-                                                uiBottom("Jamie M. Kass, Bruno Vilela, Robert P. Anderson", 'rmarkdown', 'JJ Allaire, Joe Cheng, Yihui Xie, Jonathan McPherson, 
+                                                uiBottom("Jamie M. Kass, Gonzalo E. Pinilla-Buitrago, Bruno Vilela, Robert P. Anderson", 'rmarkdown', 'JJ Allaire, Joe Cheng, Yihui Xie, Jonathan McPherson, 
                                                        Winston Chang, Jeff Allen, Hadley Wickham, Aron Atkins, Rob Hyndman, Ruben Arslan'), br(),
                                                 uiBottom(NULL, 'knitr', 'Yihui Xie')
                                )
